@@ -28,7 +28,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
         """
         self.__width = width
         Gtk.Bin.__init__(self)
-        InfoController.__init__(self, width)
+        InfoController.__init__(self)
         ProgressController.__init__(self)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/MiniPlayer.ui")
@@ -60,8 +60,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
             @param width as int
         """
         self.__width = width
-        InfoController.__init__(self, width)
-        InfoController.on_current_changed(self, App().player)
+        InfoController.on_current_changed(self, width, None)
 
     def do_get_preferred_width(self):
         """
@@ -126,7 +125,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
         """
         if App().player.current_track.id is not None:
             self.show()
-        InfoController.on_current_changed(self, player)
+        InfoController.on_current_changed(self, self.__width, None)
         ProgressController.on_current_changed(self, player)
 
     def __on_status_changed(self, player):
