@@ -16,6 +16,7 @@ from gettext import gettext as _
 from gettext import ngettext as ngettext
 
 from lollypop.define import App
+from lollypop.logger import Logger
 from lollypop.database import Database
 from lollypop.database_history import History
 from lollypop.helper_dbus import DBusHelper
@@ -52,8 +53,8 @@ class Settings(Gio.Settings):
             if filename:
                 uris = [GLib.filename_to_uri(filename)]
             else:
-                print("You need to add a music uri"
-                      " to org.gnome.Lollypop in dconf")
+                Logger.info("You need to add a music uri"
+                            " to org.gnome.Lollypop in dconf")
         return list(uris)
 
 
@@ -76,8 +77,9 @@ class SettingsDialog:
         self.__progress = builder.get_object("progress")
         self.__infobar = builder.get_object("infobar")
         self.__reset_button = builder.get_object("reset_button")
-        if App().lastfm is None or App().lastfm.is_goa:
-            builder.get_object("lastfm_grid").hide()
+        if App().lastfm is not None and App().lastfm.is_goa:
+            builder.get_object("lastfm_error_label").set_text(
+                _('Using "Gnome Online Accounts" settings'))
         if App().scanner.is_locked():
             builder.get_object("reset_button").set_sensitive(False)
         artists = App().artists.count()
@@ -91,10 +93,10 @@ class SettingsDialog:
             ngettext("%d track", "%d tracks", tracks) % tracks)
 
         self.__popover_transitions = builder.get_object("popover-transitions")
-        scale_transition_duration = builder.get_object(
+        self.__scale_transition_duration = builder.get_object(
             "scale_transition_duration")
-        scale_transition_duration.set_range(1, 20)
-        scale_transition_duration.set_value(
+        self.__scale_transition_duration.set_range(1, 20)
+        self.__scale_transition_duration.set_value(
             App().settings.get_value("transition-duration").get_int32())
 
         self.__popover_compilations = builder.get_object(
@@ -237,8 +239,9 @@ class SettingsDialog:
             self.__lastfm_password = builder.get_object("lastfm_password")
             helper.get("lastfm",
                        self.__on_get_password)
-            builder.get_object("lastfm_grid").set_sensitive(True)
-            builder.get_object("lastfm_error_label").hide()
+            if not App().lastfm.is_goa:
+                builder.get_object("lastfm_grid").set_sensitive(True)
+                builder.get_object("lastfm_error_label").hide()
         #
         # Libre.fm tab
         #
@@ -341,6 +344,8 @@ class SettingsDialog:
             @param widget as Gtk.Button
         """
         self.__popover_transitions.popup()
+        # https://gitlab.gnome.org/GNOME/pango/issues/309
+        self.__scale_transition_duration.set_draw_value(True)
 
     def _on_switch_transitions_state_set(self, widget, state):
         """
@@ -531,7 +536,8 @@ class SettingsDialog:
             self.__infobar.hide()
             self.__reset_database(track_ids, len(track_ids), history)
         except Exception as e:
-            print("Application::_on_confirm_button_clicked():", e)
+            Logger.error("SettingsDialog::_on_confirm_button_clicked(): %s" %
+                         e)
 
     def _on_reset_button_clicked(self, widget):
         """
@@ -582,24 +588,7 @@ class SettingsDialog:
                              fm,
                              callback)
         except Exception as e:
-            print("Settings::__update_fm_settings(): %s" % e)
-
-    def __mix_long_func(self, args):
-        """
-            Show popover
-            @param args as []
-        """
-        if App().settings.get_value("show-compilations"):
-            self.__popover_compilations.popup()
-
-    def __mix_short_func(self, args):
-        """
-            Activate switch
-            @param args as []
-        """
-        # FIXME use *args in TouchHelper (now I know how it works)
-        args[0].set_active(not args[0].get_active())
-        return True
+            Logger.error("SettingsDialog::__update_fm_settings(): %s" % e)
 
     def __set_outputs(self, combo):
         """
